==> igloo_0_1_7.zip: igloo_0_1_7/igloo/add_relation.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
// 
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include "config/config_igloo.inc.php";
include "inc/header.inc.php";

if (isset($_REQUEST['friend'])) {
	$friend_id = $_REQUEST['friend'];
}

elseif (isset($_SESSION['user_homepage'])) {
	header("Location: " . $_SESSION['user_homepage']."?". strip_tags(SID));
	exit;
}
else {
	header("Location: index.php?". strip_tags(SID));
	exit;
}


//setup sn
require_once('class/SocialNetwork.class.php');
$sn = new Socialnetwork($me['user_id'], $db, null);
$sn->relation_type_ids = $c_node['user']['relation_type'];
$sn->status_ids = $c_node['user']['status'];


//update relation
if ($sn->updateRelationType($friend_id)) {
	
	$friend_details = $user->getUser($friend_id);
	
	//get text files
	$body_im_txt = readTxtFile($languageTextPath . "/im_new_relation.txt.php");
	$body_im_txt = str_replace("NAME",$friend_details['user_firstname'] , $body_im_txt);
	$body_im_txt = str_replace("FRIEND", $_SESSION['user_firstname'], $body_im_txt);
	//send invites
	$im->sendMessage($friend_id, $lang['subject_im_relation_accepted'], $body_im_txt);

}

$db->Close();

//redirect to my_friends.php
header("Location: sn_list.php?relation=1&". strip_tags(SID));
exit;



?>

==> igloo_0_1_9.zip: igloo_0_1_9/igloo/add_relation.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
// 
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include "config/config_igloo.inc.php";
include "inc/header.inc.php";

if (isset($_REQUEST['friend'])) {
	$friend_id = $_REQUEST['friend'];
}

elseif (isset($_SESSION['user_homepage'])) {
	header("Location: " . $_SESSION['user_homepage']."?". strip_tags(SID));
	exit;
}
else {
	header("Location: index.php?". strip_tags(SID));
	exit;
}


//setup sn
require_once('class/SocialNetwork.class.php');
$sn = new Socialnetwork($me['user_id'], $db, null);
$sn->relation_type_ids = $c_node['user']['relation_type'];
$sn->status_ids = $c_node['user']['status'];


//update relation
if ($sn->updateRelationType($friend_id)) {
	
	$friend_details = $user->getUser($friend_id);
	
	//get text files
	$body_im_txt = readTxtFile($languageTextPath . "/im_new_relation.txt.php");
	$body_im_txt = str_replace("SYS_KEYWORD_NAME",$friend_details['user_firstname'] , $body_im_txt);
	$body_im_txt = str_replace("SYS_KEYWORD_RELATION", $_SESSION['user_firstname'], $body_im_txt);
	//send invites
	$im->sendMessage($friend_id, $lang['subject_im_relation_accepted'], $body_im_txt);

}

$db->Close();

//redirect to my_friends.php
header("Location: sn_list.php?relation=1&". strip_tags(SID));
exit;



?>
